@@ -7,8 +7,9 @@ from calendar import monthrange
 from datetime import date, timedelta, datetime
 from pathlib import Path
 import sys
+import functools
 
-from calverter import Calverter
+import convertdate
 from dateutil import easter
 from lunardate import LunarDate
 from dateutil import relativedelta as rd
@@ -80,10 +81,12 @@ class ChristianMixin:
     ash_wednesday_label = "Ash Wednesday"
     include_palm_sunday = False
     include_holy_thursday = False
+    holy_thursday_label = "Holy Thursday"
     include_good_friday = False
     good_friday_label = "Good Friday"
     include_easter_monday = False
     include_easter_saturday = False
+    easter_saturday_label = "Easter Saturday"
     include_easter_sunday = False
     include_all_saints = False
     include_immaculate_conception = False
@@ -198,11 +201,15 @@ class ChristianMixin:
         if self.include_palm_sunday:
             days.append((self.get_palm_sunday(year), "Palm Sunday"))
         if self.include_holy_thursday:
-            days.append((self.get_holy_thursday(year), "Holy Thursday"))
+            days.append(
+                (self.get_holy_thursday(year), self.holy_thursday_label)
+            )
         if self.include_good_friday:
             days.append((self.get_good_friday(year), self.good_friday_label))
         if self.include_easter_saturday:
-            days.append((self.get_easter_saturday(year), "Easter Saturday"))
+            days.append(
+                (self.get_easter_saturday(year), self.easter_saturday_label)
+            )
         if self.include_easter_sunday:
             days.append((self.get_easter_sunday(year), "Easter Sunday"))
         if self.include_easter_monday:
@@ -226,7 +233,7 @@ class ChristianMixin:
                 date(year, 12, 26),
                 self.boxing_day_label,
                 indication="Day after Christmas",
-                observe_after=christmas
+                observe_after=christmas,
             )
             days.append(boxing_day)
         if self.include_ascension:
@@ -418,23 +425,22 @@ class CalverterMixin:
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.calverter = Calverter()
         if self.conversion_method is None:
             raise NotImplementedError
 
     def converted(self, year):
-        conversion_method = getattr(
-            self.calverter, f'jd_to_{self.conversion_method}'
-        )
         current = date(year, 1, 1)
+        delta = timedelta(days=1)
         days = []
         while current.year == year:
-            julian_day = self.calverter.gregorian_to_jd(
-                current.year,
-                current.month,
-                current.day)
-            days.append(conversion_method(julian_day))
-            current = current + timedelta(days=1)
+            days.append(
+                self.conversion_method.from_gregorian(
+                    current.year,
+                    current.month,
+                    current.day
+                )
+            )
+            current += delta
         return days
 
     def calverted_years(self, year):
@@ -457,13 +463,10 @@ class CalverterMixin:
                       'this Islamic calendar computation may be wrong.')
         days = super().get_variable_days(year)
         years = self.calverted_years(year)
-        conversion_method = getattr(
-            self.calverter, f'{self.conversion_method}_to_jd')
         for month, day, label in self.get_islamic_holidays():
             for y in years:
-                jd = conversion_method(y, month, day)
-                g_year, g_month, g_day = self.calverter.jd_to_gregorian(jd)
-                holiday = date(g_year, g_month, g_day)
+                g_date = self.conversion_method.to_gregorian(y, month, day)
+                holiday = date(*g_date)
 
                 # Only add a delta if necessary
                 delta = self.get_delta_islamic_holidays(year)
@@ -479,7 +482,7 @@ class IslamicMixin(SeriesShiftMixin, CalverterMixin):
 
     WEEKEND_DAYS = (FRI, SAT)
 
-    conversion_method = 'islamic'
+    conversion_method = convertdate.islamic
     include_prophet_birthday = False
     include_day_after_prophet_birthday = False
     include_start_ramadan = False
@@ -487,6 +490,7 @@ class IslamicMixin(SeriesShiftMixin, CalverterMixin):
     length_eid_al_fitr = 1
     eid_al_fitr_label = "Eid al-Fitr"
     include_eid_al_adha = False
+    eid_al_adha_label = "Eid al-Adha"
     length_eid_al_adha = 1
     include_day_of_sacrifice = False
     day_of_sacrifice_label = "Eid al-Adha"
@@ -515,7 +519,7 @@ class IslamicMixin(SeriesShiftMixin, CalverterMixin):
                 days.append((10, x + 1, self.eid_al_fitr_label))
         if self.include_eid_al_adha:
             for x in range(self.length_eid_al_adha):
-                days.append((12, x + 10, "Eid al-Adha"))
+                days.append((12, x + 10, self.eid_al_adha_label))
         if self.include_day_of_sacrifice:
             days.append((12, 10, self.day_of_sacrifice_label))
         if self.include_laylat_al_qadr:
@@ -524,15 +528,6 @@ class IslamicMixin(SeriesShiftMixin, CalverterMixin):
                           " to compute it. You'll have to add it manually.")
         return tuple(days)
 
-    def get_calendar_holidays(self, year):
-        self.series_requiring_shifts = [self.eid_al_fitr_label,
-                                        self.day_of_sacrifice_label]
-        return super().get_calendar_holidays(year)
-
-
-class JalaliMixin(CalverterMixin):
-    conversion_method = 'jalali'
-
 
 class CoreCalendar:
 
@@ -598,6 +593,7 @@ class CoreCalendar:
         day = cleaned_date(day)
         return {day: label for day, label in self.holidays(day.year)}.get(day)
 
+    @functools.lru_cache()
     def get_observed_date(self, holiday):
         """
         The date the holiday is observed for this calendar. If the holiday
@@ -1084,6 +1080,7 @@ class Calendar(CoreCalendar):
     Take care of the New Years Day, which is almost a worldwide holiday.
     """
     include_new_years_day = True
+    include_new_years_eve = False
     shift_new_years_day = False
     include_labour_day = False
     labour_day_label = "Labour Day"
@@ -1094,14 +1091,11 @@ class Calendar(CoreCalendar):
     def get_fixed_holidays(self, year):
         days = super().get_fixed_holidays(year)
         if self.include_new_years_day:
-            days.insert(
-                0, (date(year, 1, 1), "New year")
-            )
-
+            days.insert(0, (date(year, 1, 1), "New year"))
+        if self.include_new_years_eve:
+            days.append((date(year, 12, 31), "New Year's eve"))
         if self.include_labour_day:
-            days.append(
-                (date(year, 5, 1), self.labour_day_label)
-            )
+            days.append((date(year, 5, 1), self.labour_day_label))
         return days
 
     def get_variable_days(self, year):
